.. _ydoc directive_3 directive_3_1:

``directive_3_1``
=================

This is a description of Directive 3.1

Subdirective:

.. toctree::
   :maxdepth: 1

   directive_3_1/directive_3_1_1


----

This page was automatically generated by **ycleptic** v1.8.0 on 2025-08-04.